==> mx-service-manager_24.3.tar.xz: BUILD/translations/mx-service-manager_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>MX Service Manager</source>
        <translation>MX Service Manager</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>About this application</source>
        <translation>Over deze toepassing</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <location filename="../mainwindow.cpp" line="157"/>
        <location filename="../mainwindow.cpp" line="317"/>
        <source>&amp;Enable at boot</source>
        <translation>&amp;Inschakelen bij opstarten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>&amp;About...</source>
        <translation>&amp;Over...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="126"/>
        <source>Display help </source>
        <translation>Toon help</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="129"/>
        <source>&amp;Help</source>
        <translation>&amp;Help</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="171"/>
        <source>&amp;Close</source>
        <translation>&amp;Sluiten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="227"/>
        <location filename="../mainwindow.cpp" line="278"/>
        <source>Services enabled at boot</source>
        <translation>Services ingeschakeld bij opstarten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="232"/>
        <location filename="../mainwindow.cpp" line="279"/>
        <source>Services disabled at boot</source>
        <translation>Services uitgeschakeld bij opstarten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="268"/>
        <source>search</source>
        <translation>zoeken</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <location filename="../mainwindow.cpp" line="139"/>
        <source>&amp;Stop</source>
        <translation>&amp;Stop</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="297"/>
        <source>This tool lists services and daemons (processes that run in the background) found on this system. Be careful to avoid stopping something that might disrupt a critical component; best to leave it alone if you don&apos;t know what it is.</source>
        <translation>Deze tool geeft een lijst van services en daemons (processen die op de achtergrond draaien) die op dit systeem zijn gevonden. Wees voorzichtig om te voorkomen dat je iets stopt dat een kritisch onderdeel zou kunnen verstoren; het beste is om het met rust te laten als je niet weet wat het is.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <source>All services</source>
        <translation>Alle services</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="222"/>
        <location filename="../mainwindow.cpp" line="277"/>
        <source>Running services</source>
        <translation>Lopende services</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="136"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Quit application</source>
        <translation>Verlaat de applicatie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="178"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="278"/>
        <location filename="../mainwindow.cpp" line="68"/>
        <location filename="../mainwindow.cpp" line="81"/>
        <source>Loading...</source>
        <translation>Laden...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="62"/>
        <location filename="../mainwindow.cpp" line="319"/>
        <location filename="../mainwindow.cpp" line="326"/>
        <location filename="../mainwindow.cpp" line="347"/>
        <location filename="../mainwindow.cpp" line="356"/>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="63"/>
        <source>Could not determine the init system. This program is supposed to run either with systemd or sysvinit</source>
        <translation>Kon het init-systeem niet bepalen. Dit programma wordt verondersteld te draaien met systemd of sysvinit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="144"/>
        <location filename="../mainwindow.cpp" line="345"/>
        <source>S&amp;tart</source>
        <translation>S&amp;tart</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="150"/>
        <source>&amp;Disable at boot</source>
        <translation>&amp;Uitschakelen bij opstarten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="286"/>
        <source>%1 total services, %2 currently &lt;font color=&apos;%3&apos;&gt;running&lt;/font&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="288"/>
        <source>%1 &lt;font color=&apos;%2&apos;&gt;enabled&lt;/font&gt; at boot, but not running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>About %1</source>
        <translation>Over %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="303"/>
        <source>Version: </source>
        <translation>Versie:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="304"/>
        <source>Service and daemon manager</source>
        <translation>Service- en daemonmanager</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="307"/>
        <source>%1 License</source>
        <translation>%1 Licentie</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="319"/>
        <source>Could not enable %1</source>
        <translation>Kon %1 niet inschakelen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="323"/>
        <location filename="../mainwindow.cpp" line="330"/>
        <location filename="../mainwindow.cpp" line="352"/>
        <location filename="../mainwindow.cpp" line="361"/>
        <source>Success</source>
        <translation>Gelukt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="323"/>
        <source>%1 was enabled at boot time.</source>
        <translation>%1 was ingeschakeld tijdens het opstarten.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>Could not disable %1</source>
        <translation>Kon %1 niet uitschakelen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="330"/>
        <source>%1 was disabled.</source>
        <translation>%1 was uitgeschakeld.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="337"/>
        <source>%1 Help</source>
        <translation>%1 Help</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="347"/>
        <source>Could not start %1</source>
        <translation>Kon %1 niet starten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="352"/>
        <source>%1 was started.</source>
        <translation>%1 is gestart.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="356"/>
        <source>Could not stop %1</source>
        <translation>Kon %1 niet stoppen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="361"/>
        <source>%1 was stopped.</source>
        <translation>%1 is gestopt.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>License</source>
        <translation>Licentie</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="71"/>
        <location filename="../about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Changelog</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Ongedaan maken</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Sluiten</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <location filename="../main.cpp" line="82"/>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>U lijkt ingelogd te zijn als root, gelieve uit te loggen en in te loggen als normale gebruiker om dit programma te gebruiken.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>You must run this program with admin access.</source>
        <translation>Je moet dit programma uitvoeren met admin-toegang.</translation>
    </message>
    <message>
        <location filename="../service.cpp" line="116"/>
        <source>Could not find service description</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> mx-service-manager_24.3.02.tar.xz: BUILD/translations/mx-service-manager_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="302"/>
        <location filename="../ui_mainwindow.h" line="225"/>
        <source>MX Service Manager</source>
        <translation>MX Service Manager</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <location filename="../mainwindow.cpp" line="157"/>
        <location filename="../mainwindow.cpp" line="317"/>
        <location filename="../ui_mainwindow.h" line="226"/>
        <source>&amp;Enable at boot</source>
        <translation>&amp;Inschakelen bij opstarten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <location filename="../ui_mainwindow.h" line="228"/>
        <source>About this application</source>
        <translation>Over deze toepassing</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <location filename="../ui_mainwindow.h" line="230"/>
        <source>&amp;About...</source>
        <translation>&amp;Over...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <location filename="../ui_mainwindow.h" line="232"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="126"/>
        <location filename="../ui_mainwindow.h" line="236"/>
        <source>Display help </source>
        <translation>Toon help</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="129"/>
        <location filename="../ui_mainwindow.h" line="238"/>
        <source>&amp;Help</source>
        <translation>&amp;Help</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="136"/>
        <location filename="../ui_mainwindow.h" line="240"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <location filename="../ui_mainwindow.h" line="243"/>
        <source>Quit application</source>
        <translation>Verlaat de applicatie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="171"/>
        <location filename="../ui_mainwindow.h" line="245"/>
        <source>&amp;Close</source>
        <translation>&amp;Sluiten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="178"/>
        <location filename="../ui_mainwindow.h" line="247"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <location filename="../mainwindow.cpp" line="139"/>
        <location filename="../ui_mainwindow.h" line="250"/>
        <source>&amp;Stop</source>
        <translation>&amp;Stop</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <location filename="../ui_mainwindow.h" line="251"/>
        <source>All services</source>
        <translation>Alle services</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="222"/>
        <location filename="../mainwindow.cpp" line="277"/>
        <location filename="../ui_mainwindow.h" line="252"/>
        <source>Running services</source>
        <translation>Lopende services</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="227"/>
        <location filename="../mainwindow.cpp" line="278"/>
        <location filename="../ui_mainwindow.h" line="253"/>
        <source>Services enabled at boot</source>
        <translation>Services ingeschakeld bij opstarten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="232"/>
        <location filename="../mainwindow.cpp" line="279"/>
        <location filename="../ui_mainwindow.h" line="254"/>
        <source>Services disabled at boot</source>
        <translation>Services uitgeschakeld bij opstarten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="268"/>
        <location filename="../ui_mainwindow.h" line="257"/>
        <source>search</source>
        <translation>zoeken</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="278"/>
        <location filename="../mainwindow.cpp" line="68"/>
        <location filename="../mainwindow.cpp" line="81"/>
        <location filename="../ui_mainwindow.h" line="258"/>
        <source>Loading...</source>
        <translation>Laden...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="297"/>
        <location filename="../ui_mainwindow.h" line="259"/>
        <source>This tool lists services and daemons (processes that run in the background) found on this system. Be careful to avoid stopping something that might disrupt a critical component; best to leave it alone if you don&apos;t know what it is.</source>
        <translation>Deze tool geeft een lijst van services en daemons (processen die op de achtergrond draaien) die op dit systeem zijn gevonden. Wees voorzichtig om te voorkomen dat je iets stopt dat een kritisch onderdeel zou kunnen verstoren; het beste is om het met rust te laten als je niet weet wat het is.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="62"/>
        <location filename="../mainwindow.cpp" line="319"/>
        <location filename="../mainwindow.cpp" line="326"/>
        <location filename="../mainwindow.cpp" line="347"/>
        <location filename="../mainwindow.cpp" line="356"/>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="63"/>
        <source>Could not determine the init system. This program is supposed to run either with systemd or sysvinit</source>
        <translation>Kon het init-systeem niet bepalen. Dit programma wordt verondersteld te draaien met systemd of sysvinit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="144"/>
        <location filename="../mainwindow.cpp" line="345"/>
        <source>S&amp;tart</source>
        <translation>S&amp;tart</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="150"/>
        <source>&amp;Disable at boot</source>
        <translation>&amp;Uitschakelen bij opstarten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="286"/>
        <source>%1 total services, %2 currently &lt;font color=&apos;%3&apos;&gt;running&lt;/font&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="288"/>
        <source>%1 &lt;font color=&apos;%2&apos;&gt;enabled&lt;/font&gt; at boot, but not running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>About %1</source>
        <translation>Over %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="303"/>
        <source>Version: </source>
        <translation>Versie:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="304"/>
        <source>Service and daemon manager</source>
        <translation>Service- en daemonmanager</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="307"/>
        <source>%1 License</source>
        <translation>%1 Licentie</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="319"/>
        <source>Could not enable %1</source>
        <translation>Kon %1 niet inschakelen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="323"/>
        <location filename="../mainwindow.cpp" line="330"/>
        <location filename="../mainwindow.cpp" line="352"/>
        <location filename="../mainwindow.cpp" line="361"/>
        <source>Success</source>
        <translation>Gelukt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="323"/>
        <source>%1 was enabled at boot time.</source>
        <translation>%1 was ingeschakeld tijdens het opstarten.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>Could not disable %1</source>
        <translation>Kon %1 niet uitschakelen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="330"/>
        <source>%1 was disabled.</source>
        <translation>%1 was uitgeschakeld.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="337"/>
        <source>%1 Help</source>
        <translation>%1 Help</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="347"/>
        <source>Could not start %1</source>
        <translation>Kon %1 niet starten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="352"/>
        <source>%1 was started.</source>
        <translation>%1 is gestart.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="356"/>
        <source>Could not stop %1</source>
        <translation>Kon %1 niet stoppen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="361"/>
        <source>%1 was stopped.</source>
        <translation>%1 is gestopt.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>License</source>
        <translation>Licentie</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="71"/>
        <location filename="../about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Changelog</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Ongedaan maken</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Sluiten</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <location filename="../main.cpp" line="82"/>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>U lijkt ingelogd te zijn als root, gelieve uit te loggen en in te loggen als normale gebruiker om dit programma te gebruiken.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>You must run this program with admin access.</source>
        <translation>Je moet dit programma uitvoeren met admin-toegang.</translation>
    </message>
    <message>
        <location filename="../service.cpp" line="116"/>
        <source>Could not find service description</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
